.. module:: finol.evaluation_layer

finol.evaluation_layer
======================

The :mod:`~finol.evaluation_layer` module contains evaluation layer related classes and functions.

.. autosummary::
   :toctree: generated/
   :nosignatures:

   finol.evaluation_layer.BenchmarkLoader
   finol.evaluation_layer.DistillerSelector
   finol.evaluation_layer.EconomicDistiller
   finol.evaluation_layer.MetricCaculator
   finol.evaluation_layer.ModelEvaluator
